"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function validate(target, options) {
    var keys = Reflect.getMetadata("validation", target);
    var errorMessages = [];
    if (Array.isArray(keys)) {
        for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
            var key = keys_1[_i];
            var rules = Reflect.getMetadata("validation", target, key);
            if (!Array.isArray(rules)) {
                continue;
            }
            for (var _a = 0, rules_1 = rules; _a < rules_1.length; _a++) {
                var rule = rules_1[_a];
                var error = rule.run(target, target[key], key);
                if (error) {
                    var errorBag = {
                        key: key,
                        message: error
                    };
                    errorMessages.push(errorBag);
                }
            }
        }
    }
    if (options && options.throw && errorMessages.length) {
        throw errorMessages;
    }
    return errorMessages;
}
exports.validate = validate;
function isValid(target) {
    var validationResult = validate(target);
    return validationResult.length === 0;
}
exports.isValid = isValid;
//# sourceMappingURL=validate.js.map